@@ -3,7 +3,7 @@ use warnings;
 
 package Thread::IID;
 BEGIN {
-  $Thread::IID::VERSION = '0.010_001';
+  $Thread::IID::VERSION = '0.010002_002';
 }
 
  use 5.008001;
@@ -39,11 +39,11 @@ __END__
 
 =head1 NAME
 
-Thread::IID - Perl extension for obtaining unique interpreter IDs
+Thread::IID - unique perl Interpreter IDs
 
 =head1 VERSION
 
-version 0.010_001
+version 0.010002_002
 
 =head1 SYNOPSIS
 
@@ -53,25 +53,30 @@ version 0.010_001
 
 =head1 DESCRIPTION
 
-This module provides a single function for identifying Perl interpreter 
-instances.
+This provides an identifier to distinguish Perl interpreter instances.
+
+In environments like L<mod_perl|mod_perl>, where interpreters are 
+cloned and passed around between OS threads, the thread ID gives no 
+indication of which interpreter instance is actually running
+(and hence which corresponding set of values/data-structures 
+is actually being referenced)
 
 =head2 EXPORT
 
-None by default.  The following function is avaliable:
+None by default.  The following function is available:
 
 =head3 get_interpreter_id()
 
-Returns an ID for the current Perl interpreter instance.  
+Returns an integer ID for the current Perl interpreter instance.  
 
 Where multiple interpreters have been created to run in 
 threads of the current process the IDs returned will be 
-different for each interpreter, regardless of the whether 
-the interpreters are being run on distinct threads or not.
+different for each interpreter, regardless of which
+threads are running which interpreters.
 
 =head1 AUTHOR
 
-Original code by ikegami at PerlMonks.
+Original XS code is from a posting by ikegami at PerlMonks.
 Packaged by Roger Crew, E<lt>crew@cs.stanford.eduE<gt>
 
 =head1 COPYRIGHT AND LICENSE
